@@ -11,7 +11,6 @@ use Config;
 
 use Date::Simple;
 
-use File::Basename; # For basename().
 use File::Spec;
 
 use MarpaX::Demo::StringParser::Config;
@@ -34,7 +33,7 @@ has config =>
 );
 
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 # ------------------------------------------------
 
@@ -131,27 +130,6 @@ sub generate_demo_index
 
 } # End of generate_demo_index.
 
-# ------------------------------------------------
-
-sub get_files
-{
-	my($self, $dir_name, $type) = @_;
-
-	opendir(INX, $dir_name);
-	my(@file) = sort grep{/$type$/} readdir INX;
-	closedir INX;
-
-	my(%file);
-
-	for my $file_name (@file)
-	{
-		$file{basename($file_name, ".$type")} = $file_name;
-	}
-
-	return %file;
-
-} # End of get_files.
-
 # -----------------------------------------------
 
 1;
@@ -245,12 +223,6 @@ Writes C<html/index.html>.
 
 See scripts/generate.index.pl.
 
-=head2 get_files($dir_name, $type)
-
-Returns a list of files from the given $dir_name, whose type (extension) matches $type.
-
-See scripts/dot2svg.pl and scripts/ge2svg.pl.
-
 =head1 Version Numbers
 
 Version numbers < 1.00 represent development versions. From 1.00 up, they are production versions.
